@@ -4,36 +4,32 @@
  * Parts of this code are based on work Copyright (c) 2003 by Domenico
  * Andreoli.
  *
- * Copyright (c) 2008, 2009 Jan Dittberner <jan@dittberner.info>
+ * Copyright (c) 2008 Jan Dittberner <jan@dittberner.info>
  *
  * This file is part of cracklib.
  *
- * This library is free software; you can redistribute it and/or modify it
- * under the terms of the GNU Lesser General Public License as published by the
- * Free Software Foundation; either version 2.1 of the License, or (at your
- * option) any later version.
+ * cracklib is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
  *
- * This library is distributed in the hope that it will be useful, but WITHOUT
- * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
- * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
- * for more details.
+ * cracklib is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this library; if not, write to the Free Software Foundation,
- * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * You should have received a copy of the GNU General Public License
+ * along with Prua; if not, write to the Free Software Foundation,
+ * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  */
 
-#ifdef PYTHON_H
+#include <sys/types.h>
+#include <sys/stat.h>
 #include PYTHON_H
-#else
-#include <Python.h>
-#endif
 #ifdef HAVE_PTHREAD_H
 #include <pthread.h>
 #endif
-#include <crack.h>
-#include <locale.h>
-#include <libintl.h>
+#include "../lib/crack.h"
 
 #ifdef HAVE_PTHREAD_H
 static pthread_mutex_t cracklib_mutex = PTHREAD_MUTEX_INITIALIZER;
@@ -64,7 +60,8 @@ static char _cracklib_FascistCheck_doc [] =
 static PyObject *
 _cracklib_FascistCheck(PyObject *self, PyObject *args, PyObject *kwargs)
 {
-    char *candidate, *dict, *defaultdict;
+    int i;
+    char *candidate, *dict;
     const char *result;
     struct stat st;
     char *keywords[] = {"pw", "dictpath", NULL};
@@ -103,48 +100,25 @@ _cracklib_FascistCheck(PyObject *self, PyObject *args, PyObject *kwargs)
         sprintf(dictfile, "%s" DICT_SUFFIX, dict);
         if (lstat(dictfile, &st) == -1)
         {
-            PyErr_SetFromErrnoWithFilename(PyExc_OSError, dictfile);
+            PyErr_SetFromErrnoWithFilename(PyExc_OSError, dict);
             free(dictfile);
             return NULL;
         }
         free(dictfile);
     } else
     {
-        defaultdict = strdup(GetDefaultCracklibDict());
-        if (errno == ENOMEM) {
-            PyErr_SetFromErrno(PyExc_OSError);
-            return NULL;
-        }
-        dictfile = malloc(strlen(defaultdict) + sizeof(DICT_SUFFIX));
-        if (dictfile == NULL)
+        if (lstat(DEFAULT_CRACKLIB_DICT DICT_SUFFIX, &st) == -1)
         {
-            PyErr_SetFromErrnoWithFilename(PyExc_OSError, defaultdict);
-            free(defaultdict);
+            PyErr_SetFromErrnoWithFilename(PyExc_OSError,
+                                           DEFAULT_CRACKLIB_DICT);
             return NULL;
         }
-        sprintf(dictfile, "%s" DICT_SUFFIX, defaultdict);
-        if (lstat(dictfile, &st) == -1)
-        {
-            PyErr_SetFromErrnoWithFilename(PyExc_OSError, dictfile);
-            free(defaultdict);
-            free(dictfile);
-            return NULL;
-        }
-        free(dictfile);
     }
 
-	setlocale(LC_ALL, "");
-	textdomain("cracklib");
-
     LOCK();
-    result = FascistCheck(candidate, dict ? dict : defaultdict);
+    result = FascistCheck(candidate, dict ? dict : DEFAULT_CRACKLIB_DICT);
     UNLOCK();
 
-    if (defaultdict != NULL)
-    {
-        free(defaultdict);
-    }
-
     if (result != NULL)
     {
     	PyErr_SetString(PyExc_ValueError, result);
@@ -156,8 +130,8 @@ _cracklib_FascistCheck(PyObject *self, PyObject *args, PyObject *kwargs)
 static PyMethodDef
 _cracklibmethods[] =
 {
-    {"FascistCheck", (PyCFunction) _cracklib_FascistCheck,
-     METH_VARARGS | METH_KEYWORDS, _cracklib_FascistCheck_doc},
+    {"FascistCheck", _cracklib_FascistCheck, METH_VARARGS | METH_KEYWORDS,
+     _cracklib_FascistCheck_doc},
     {NULL, NULL},
 };
 
